# pyfindmaxima

[![License](https://img.shields.io/pypi/l/pyfindmaxima.svg?color=green)](https://github.com/cwood1967/pyfindmaxima/blob/master/LICENSE)
[![PyPI](https://img.shields.io/pypi/v/napari-nikon-nd2.svg?color=green)](https://pypi.org/project/pyfindmaxima)
[![Python Version](https://img.shields.io/pypi/pyversions/pyfindmaxima.svg?color=green)](https://python.org)
[![Tests](https://github.com/cwood1967/pyfindmaxima/actions/workflows/tests.yml/badge.svg)](https://github.com/cwood1967/pyfindmaxima/actions/workflows/tests.yml)
[![codecov](https://codecov.io/gh/cwood1967/pyfindmaxima/branch/master/graph/badge.svg)](https://codecov.io/gh/cwood1967/napari-nikon-nd2)

Finds local maxima in an image and returns a list of x, y coordinates. Based on the ImageJ Find Maxima plugin: [description](https://imagej.net/Find_Maxima...), [source](https://github.com/imagej/imagej1/blob/master/ij/plugin/filter/MaximumFinder.java) by Michael Schmid and Wayne Rasband.